import sklearn.metrics
import torch
from explaining_framework.metric.base import Metric


class Accuracy(Metric):
    def __init__(self, name: str):
        super().__init__(name=name, model=None)
        self.authorized_metric = [
            "precision_score",
            "jaccard_score",
            "roc_auc_score",
            "f1_score",
            "accuracy_score",
        ]

        self.load_metric(name)

    def load_metric(self, name):
        if name in self.authorized_metric:
            if name == "precision_score":
                self.metric = sklearn.metrics.precision_score
            if name == "jaccard_score":
                self.metric = sklearn.metrics.jaccard_score
            if name == "roc_auc_score":
                self.metric = sklearn.metrics.roc_auc_score
            if name == "f1_score":
                self.metric = sklearn.metrics.f1_score
            if name == "accuracy_score":
                self.metric = sklearn.metrics.accuracy_score
        else:
            raise ValueError(f"{name} is not supported")

    def forward(self, mask: torch.Tensor, target: torch.Tensor) -> float:
        if self.name == "roc_auc_score":
            return self.metric(y_score=mask, y_true=target)
        else:
            return self.metric(y_pred=mask, y_true=target)
